@@ -1,18 +1,18 @@
 estimateCommonDisp <- function(object,tol=1e-06,rowsum.filter=5)
 # Do two iterations of calculating pseudodata and estimating common dispersion, first one uses Poisson
 # Davis McCarthy, Mark Robinson, Gordon Smyth.
-# Created 2009. Last modified 1 Oct 2011.
+# Created 2009. Last modified 7 Mar 2012.
 {
 	if(!is(object,"DGEList")) stop("Currently supports DGEList objects")
 	group <- object$samples$group <- as.factor(object$samples$group)
 
 	if( all(table(group)==1) ) {
-		warning("There is no replication.  Setting common dispersion to 0.")
+		warning("There is no replication, so dispersion cannot be estimated.  Setting common dispersion to 0.")
 		q2q.out <- equalizeLibSizes(object,disp=0,null.hypothesis=FALSE)
 		object$common.dispersion=1e-16
 		object$pseudo.alt=q2q.out$pseudo
 		object$conc=q2q.out$conc
-		object$common.lib.size=q2q.out
+		object$common.lib.size=q2q.out$N
 		return(object)
 	}
 
@@ -24,7 +24,12 @@ estimateCommonDisp <- function(object,tol=1e-06,rowsum.filter=5)
 		pseudo.obj <- pseudo.obj[tags.used,]
 		common.dispersion <- .estimateCommonDisp(pseudo.obj, tol=tol)
 	}
-	new("DGEList",list(samples=object$samples, common.dispersion=common.dispersion$dispersion, counts=object$counts, pseudo.alt=q2q.out$pseudo, genes=object$genes, all.zeros=object$all.zeros, conc=q2q.out$conc, common.lib.size=q2q.out$N))
+	object$common.dispersion <- common.dispersion$dispersion
+	object$pseudo.alt <- q2q.out$pseudo
+	object$conc <- q2q.out$conc
+	object$common.lib.size <- q2q.out$N
+	object
+#	new("DGEList",list(samples=object$samples, common.dispersion=common.dispersion$dispersion, counts=object$counts, pseudo.alt=q2q.out$pseudo, genes=object$genes, all.zeros=object$all.zeros, conc=q2q.out$conc, common.lib.size=q2q.out$N))
 }
 
 .estimateCommonDisp <- function(object, tol=1e-06)
